# MetaGym

MetaGym provides abundant environments for benchmarking Reinforcement Learning and Meta Reinforcement Learning

# Environments Updating

- [LiftSim](metagym/liftsim)：Simulator for Evelvator Dispatching (Sep, 2019)

- [Quadrotor](metagym/quadrotor): 3D Quadrotor simulator for different tasks (Mar, 2020)

- [Quadrupedal](metagym/quadrupedal): Quadrupedal robot adapting to different terrains (Seq, 2021)

- [MetaMaze](metagym/metamaze): Meta maze environment for 3D visual navigation (Oct, 2021)

- [Navigator2D](metagym/navigator2d): Simple 2D navigator meta environment (Oct, 2021)

- [MetaLocomotion](metagym/metalocomotion): Locomotion simulator with diverse geometries (June, 2022)
